:orphan:



.. _sphx_glr_source_auto_examples:

ACT Example Gallery
===================

Different examples on how to read and visualize data using ACT are provided 
here.




.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This example shows how to plot timeseries of ASOS data from Chicago O&#x27;Hare airport.">

.. only:: html

 .. figure:: /source/auto_examples/images/thumb/sphx_glr_plot_asos_temp_thumb.png
     :alt: Example on plotting timeseries of ASOS data

     :ref:`sphx_glr_source_auto_examples_plot_asos_temp.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /source/auto_examples/plot_asos_temp

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This is an example of how to download and plot ceiliometer data from the SGP site over Oklahoma...">

.. only:: html

 .. figure:: /source/auto_examples/images/thumb/sphx_glr_ceil_example_thumb.png
     :alt: Example for looking at ceilometer data

     :ref:`sphx_glr_source_auto_examples_ceil_example.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /source/auto_examples/ceil_example

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Simple example for querying the ARM DQR webservice and plotting up the results">

.. only:: html

 .. figure:: /source/auto_examples/images/thumb/sphx_glr_plot_qc_thumb.png
     :alt: Example on how to query the ARM DQR webservice

     :ref:`sphx_glr_source_auto_examples_plot_qc.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /source/auto_examples/plot_qc

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Example of how to read in MET data and plot up daytime temperature averages using the add_solar...">

.. only:: html

 .. figure:: /source/auto_examples/images/thumb/sphx_glr_plot_daytime_averages_thumb.png
     :alt: Example on how to plot up daily daytime temperature averages

     :ref:`sphx_glr_source_auto_examples_plot_daytime_averages.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /source/auto_examples/plot_daytime_averages

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Example of how to read in raw data from the mini-MPL and plot out the PPI by converting it to P...">

.. only:: html

 .. figure:: /source/auto_examples/images/thumb/sphx_glr_plot_raw_minimpl_thumb.png
     :alt: Example on how to read and plot a PPI from mini-MPL

     :ref:`sphx_glr_source_auto_examples_plot_raw_minimpl.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /source/auto_examples/plot_raw_minimpl

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This example shows how to make a Skew-T plot from a sounding and calculate stability indicies. ...">

.. only:: html

 .. figure:: /source/auto_examples/images/thumb/sphx_glr_plot_skewt_thumb.png
     :alt: Example on how to plot a Skew-T plot of a sounding

     :ref:`sphx_glr_source_auto_examples_plot_skewt.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /source/auto_examples/plot_skewt

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This is an example of how to display wind rose and barb timeseries from multiple days worth of ...">

.. only:: html

 .. figure:: /source/auto_examples/images/thumb/sphx_glr_plot_rh_timeseries_thumb.png
     :alt: Example on how to plot winds and relative humidity from sounding data

     :ref:`sphx_glr_source_auto_examples_plot_rh_timeseries.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /source/auto_examples/plot_rh_timeseries

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This is a simple example for how to plot a timeseries of sounding data from the ARM SGP site.">

.. only:: html

 .. figure:: /source/auto_examples/images/thumb/sphx_glr_plot_sonde_thumb.png
     :alt: Example on how to plot a timeseries of sounding data

     :ref:`sphx_glr_source_auto_examples_plot_sonde.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /source/auto_examples/plot_sonde

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This example shows how to calculate course and speed over ground of the ship and use it to corr...">

.. only:: html

 .. figure:: /source/auto_examples/images/thumb/sphx_glr_correct_ship_wind_data_thumb.png
     :alt: Example on how to correct wind data for ship motion

     :ref:`sphx_glr_source_auto_examples_correct_ship_wind_data.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /source/auto_examples/correct_ship_wind_data

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This is an example of how to display wind rose and barb timeseries from multiple days worth of ...">

.. only:: html

 .. figure:: /source/auto_examples/images/thumb/sphx_glr_plot_wind_rose_thumb.png
     :alt: Example on how to plot winds and relative humidity from sounding data

     :ref:`sphx_glr_source_auto_examples_plot_wind_rose.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /source/auto_examples/plot_wind_rose

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This is an example of how to prepare and plot data for a contour plot">

.. only:: html

 .. figure:: /source/auto_examples/images/thumb/sphx_glr_plot_contour_thumb.png
     :alt: Example for plotting up a contour plot

     :ref:`sphx_glr_source_auto_examples_plot_contour.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /source/auto_examples/plot_contour

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This example shows how to retrieve CAPE, CIN, and lifted index from a sounding.">

.. only:: html

 .. figure:: /source/auto_examples/images/thumb/sphx_glr_get_stability_indices_example_thumb.png
     :alt: Example on how to retrieve stability indicies from a sounding

     :ref:`sphx_glr_source_auto_examples_get_stability_indices_example.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /source/auto_examples/get_stability_indices_example

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This is an example of how to use 2 dimentional DataArrays containing multiple 1 dimentional dat...">

.. only:: html

 .. figure:: /source/auto_examples/images/thumb/sphx_glr_force_line_plot_qc_thumb.png
     :alt: Example for working with embedded quality control variables

     :ref:`sphx_glr_source_auto_examples_force_line_plot_qc.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /source/auto_examples/force_line_plot_qc

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This is an example of how to download and plot multiple datasets at a time.">

.. only:: html

 .. figure:: /source/auto_examples/images/thumb/sphx_glr_multidata_example_thumb.png
     :alt: Example on how to plot multiple datasets at a time

     :ref:`sphx_glr_source_auto_examples_multidata_example.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /source/auto_examples/multidata_example

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="In this example, the VISST">

.. only:: html

 .. figure:: /source/auto_examples/images/thumb/sphx_glr_xsection_example_thumb.png
     :alt: Example for plotting multidimensional cross sections

     :ref:`sphx_glr_source_auto_examples_xsection_example.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /source/auto_examples/xsection_example

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This is an example of how to change units in the xarray dataset.">

.. only:: html

 .. figure:: /source/auto_examples/images/thumb/sphx_glr_change_units_thumb.png
     :alt: Example for changing units in dataset

     :ref:`sphx_glr_source_auto_examples_change_units.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /source/auto_examples/change_units

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This is an example of how to calculate a weighted average from the MET TBRG, ORG and PWD.  This...">

.. only:: html

 .. figure:: /source/auto_examples/images/thumb/sphx_glr_weighted_average_example_thumb.png
     :alt: Example for calculating a weighted average

     :ref:`sphx_glr_source_auto_examples_weighted_average_example.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /source/auto_examples/weighted_average_example

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This is an example of how to use existing or create new quality control varibles. All the tests...">

.. only:: html

 .. figure:: /source/auto_examples/images/thumb/sphx_glr_qc_example_thumb.png
     :alt: Example for working with embedded quality control variables

     :ref:`sphx_glr_source_auto_examples_qc_example.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /source/auto_examples/qc_example
.. raw:: html

    <div class="sphx-glr-clear"></div>



.. only :: html

 .. container:: sphx-glr-footer
    :class: sphx-glr-footer-gallery


  .. container:: sphx-glr-download sphx-glr-download-python

    :download:`Download all examples in Python source code: auto_examples_python.zip </source/auto_examples/auto_examples_python.zip>`



  .. container:: sphx-glr-download sphx-glr-download-jupyter

    :download:`Download all examples in Jupyter notebooks: auto_examples_jupyter.zip </source/auto_examples/auto_examples_jupyter.zip>`


.. only:: html

 .. rst-class:: sphx-glr-signature

    `Gallery generated by Sphinx-Gallery <https://sphinx-gallery.github.io>`_
